@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ IntroductionWebEngineView::IntroductionWebEngineView(QWidget *parent)
     connect(pageEngine, &IntroductionWebEnginePage::urlClicked, this, &IntroductionWebEngineView::openUrl);
 }
 
-IntroductionWebEngineView::~IntroductionWebEngineView()
-{
-}
+IntroductionWebEngineView::~IntroductionWebEngineView() = default;
 
 void IntroductionWebEngineView::contextMenuEvent(QContextMenuEvent *)
 {
